@@ -36,11 +36,25 @@ to restore the original data types
 from .jfile import load, save, show, loadt, savet, loadb, saveb, jext
 from .jdata import encode, decode, jdtype, jsonfilter
 
-__version__ = '0.4.4'
-__all__ = ['load','save','show','loadt', 'savet', 'loadb', 'saveb','encode', 'decode', 'jdtype','jsonfilter','jext']
+__version__ = "0.5.0"
+__all__ = [
+    "load",
+    "save",
+    "show",
+    "loadt",
+    "savet",
+    "loadb",
+    "saveb",
+    "encode",
+    "decode",
+    "jdtype",
+    "jsonfilter",
+    "jext",
+]
 __license__ = """Apache license 2.0, Copyright (c) 2019-2022 Qianqian Fang"""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import cmd
+
     cmd.main()
