@@ -4,7 +4,7 @@ File IO to load/decode JData-based files to Python data or encode/save Python da
 Copyright (c) 2019-2022 Qianqian Fang <q.fang at neu.edu>
 """
 
-__all__ = ['load','save','show','loadt','savet','loadb','saveb','jext']
+__all__ = ["load", "save", "show", "loadt", "savet", "loadb", "saveb", "jext"]
 
 ##====================================================================================
 ## dependent libraries
@@ -19,12 +19,16 @@ from collections import OrderedDict
 ## global variables
 ##====================================================================================
 
-jext={'t':['.json','.jdt','.jdat','.jnii','.jmsh','.jnirs'], 'b':['.ubj','.bjd','.jdb','.jbat','.bnii','.bmsh','.jamm','.bnirs']};
+jext = {
+    "t": [".json", ".jdt", ".jdat", ".jnii", ".jmsh", ".jnirs"],
+    "b": [".ubj", ".bjd", ".jdb", ".jbat", ".bnii", ".bmsh", ".jamm", ".bnirs"],
+}
 
 ##====================================================================================
 ## Loading and saving data based on file extensions
 ##====================================================================================
 
+
 def load(fname, opt={}, **kwargs):
     """@brief Loading a JData file (binary or text) according to the file extension
 
@@ -34,12 +38,16 @@ def load(fname, opt={}, **kwargs):
     spl = os.path.splitext(fname)
     ext = spl[1].lower()
 
-    if(ext in jext['t']):
-        return loadt(fname, opt, **kwargs);
-    elif(ext in jext['b']):
-        return loadb(fname, opt, **kwargs);
+    if ext in jext["t"]:
+        return loadt(fname, opt, **kwargs)
+    elif ext in jext["b"]:
+        return loadb(fname, opt, **kwargs)
     else:
-        raise Exception('JData', 'file extension is not recognized, accept (' + ','.join(jext['t']) + ';' + ','.join(jext['b']) +')')
+        raise Exception(
+            "JData",
+            "file extension is not recognized, accept (" + ",".join(jext["t"]) + ";" + ",".join(jext["b"]) + ")",
+        )
+
 
 def save(data, fname, opt={}, **kwargs):
     """@brief Saving Python data to file (binary or text) according to the file extension
@@ -51,38 +59,44 @@ def save(data, fname, opt={}, **kwargs):
     spl = os.path.splitext(fname)
     ext = spl[1].lower()
 
-    if(ext=='ubj'):
-        kwargs.setdefault('islittle',False);
+    if ext == "ubj":
+        kwargs.setdefault("islittle", False)
 
-    if(ext in jext['t']):
-        savet(data, fname, opt, **kwargs);
-    elif(ext in jext['b']):
-        saveb(data, fname, opt, **kwargs);
+    if ext in jext["t"]:
+        savet(data, fname, opt, **kwargs)
+    elif ext in jext["b"]:
+        saveb(data, fname, opt, **kwargs)
     else:
-        raise Exception('JData', 'file extension is not recognized, accept (' + ','.join(jext['t']) + ';' + ','.join(jext['b']) +')')
+        raise Exception(
+            "JData",
+            "file extension is not recognized, accept (" + ",".join(jext["t"]) + ";" + ",".join(jext["b"]) + ")",
+        )
+
 
 ##====================================================================================
 ## Loading and saving text-based JData (i.e. JSON) files
 ##====================================================================================
 
+
 def loadt(fname, opt={}, **kwargs):
     """@brief Loading a text-based (JSON) JData file and decode it to native Python data
 
     @param[in] fname: a text JData (JSON based) file name
     @param[in] opt: options, if opt['decode']=True or 1 (default), call jdata.decode() after loading
     """
-    kwargs.setdefault('strict',False);
-    kwargs.setdefault('object_pairs_hook',OrderedDict);
-    opt.setdefault('decode',True);
-    opt['base64']=True;
+    kwargs.setdefault("strict", False)
+    kwargs.setdefault("object_pairs_hook", OrderedDict)
+    opt.setdefault("decode", True)
+    opt["base64"] = True
 
     with open(fname, "r") as fid:
-        data=json.load(fid, **kwargs);
+        data = json.load(fid, **kwargs)
 
-    if(opt['decode']):
-        data=jd.decode(data,opt);
+    if opt["decode"]:
+        data = jd.decode(data, opt)
     return data
 
+
 def savet(data, fname, opt={}, **kwargs):
     """@brief Saving a Python data structure to a text-based JData (JSON) file
 
@@ -90,15 +104,16 @@ def savet(data, fname, opt={}, **kwargs):
     @param[in] fname: a text JData (JSON based) file name
     @param[in] opt: options, if opt['encode']=True or 1 (default), call jdata.encode() before saving
     """
-    kwargs.setdefault('default',jd.jsonfilter);
-    opt.setdefault('encode',True);
-    opt['base64']=True;
+    kwargs.setdefault("default", jd.jsonfilter)
+    opt.setdefault("encode", True)
+    opt["base64"] = True
 
-    if(opt['encode']):
-        data=jd.encode(data,opt);
+    if opt["encode"]:
+        data = jd.encode(data, opt)
 
     with open(fname, "w") as fid:
-        json.dump(data, fid, **kwargs);
+        json.dump(data, fid, **kwargs)
+
 
 def show(data, opt={}, **kwargs):
     """@brief Printing a python data as JSON string or return the JSON string (opt['string']=True)
@@ -107,33 +122,35 @@ def show(data, opt={}, **kwargs):
     @param[in] opt: options, if opt['encode']=True or 1 (default), call jdata.encode() before printing
     """
 
-    kwargs.setdefault('default',jd.jsonfilter);
-    opt.setdefault('string',False);
-    opt.setdefault('encode',True);
-    opt['base64']=True;
+    kwargs.setdefault("default", jd.jsonfilter)
+    opt.setdefault("string", False)
+    opt.setdefault("encode", True)
+    opt["base64"] = True
 
-    if(opt['encode']):
-        data=jd.encode(data,opt);
+    if opt["encode"]:
+        data = jd.encode(data, opt)
 
-    str=json.dumps(data, **kwargs);
+    str = json.dumps(data, **kwargs)
 
-    if(opt['string']):
-        return str;
+    if opt["string"]:
+        return str
     else:
-        print(str);
+        print(str)
+
 
 ##====================================================================================
 ## Loading and saving binary JData (i.e. UBJSON) files
 ##====================================================================================
 
+
 def loadb(fname, opt={}, **kwargs):
     """@brief Loading a binary (BJData/UBJSON) JData file and decode it to native Python data
 
     @param[in] fname: a binary (BJData/UBJSON based) JData file name
     @param[in] opt: options, if opt['decode']=True or 1 (default), call jdata.decode() before saving
     """
-    opt.setdefault('decode',True)
-    opt['base64']=False;
+    opt.setdefault("decode", True)
+    opt["base64"] = False
 
     try:
         import bjdata
@@ -141,11 +158,12 @@ def loadb(fname, opt={}, **kwargs):
         raise ImportError('To read/write binary JData files, you must install the bjdata module by "pip install bjdata"')
     else:
         with open(fname, "rb") as fid:
-            data=bjdata.load(fid,**kwargs);
-        if(opt['decode']):
-            data=jd.decode(data,opt);
+            data = bjdata.load(fid, **kwargs)
+        if opt["decode"]:
+            data = jd.decode(data, opt)
         return data
 
+
 def saveb(data, fname, opt={}, **kwargs):
     """@brief Saving a Python data structure to a binary JData (BJData/UBJSON) file
 
@@ -153,17 +171,18 @@ def saveb(data, fname, opt={}, **kwargs):
     @param[in] fname: a binary (BJData/UBJSON based) JData file name
     @param[in] opt: options, if opt['encode']=True or 1 (default), call jdata.encode() before saving
     """
-    opt.setdefault('encode',True)
+    opt.setdefault("encode", True)
 
     try:
         import bjdata
     except ImportError:
         raise ImportError('To read/write binary JData files, you must install the bjdata module by "pip install bjdata"')
     else:
-        if(opt['encode']):
-            data=jd.encode(data,opt);
+        if opt["encode"]:
+            data = jd.encode(data, opt)
         with open(fname, "wb") as fid:
-            bjdata.dump(data, fid,**kwargs);
+            bjdata.dump(data, fid, **kwargs)
+
 
 ##====================================================================================
 ## helper functions
